# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/billing_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.billing.v1 import billing_account_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2
from yandex.cloud.billing.v1 import billable_object_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billable__object__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/billing/v1/billing_account_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a-yandex/cloud/billing/v1/billing_account.proto\x1a-yandex/cloud/billing/v1/billable_object.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x18GetBillingAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"Z\n\x1aListBillingAccountsRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n\x1bListBillingAccountsResponse\x12\x41\n\x10\x62illing_accounts\x18\x01 \x03(\x0b\x32\'.yandex.cloud.billing.v1.BillingAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8b\x01\n!ListBillableObjectBindingsRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8f\x01\n\"ListBillableObjectBindingsResponse\x12P\n\x18\x62illable_object_bindings\x18\x01 \x03(\x0b\x32..yandex.cloud.billing.v1.BillableObjectBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x19\x42indBillableObjectRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x0f\x62illable_object\x18\x02 \x01(\x0b\x32\'.yandex.cloud.billing.v1.BillableObject\"8\n\x1a\x42indBillableObjectMetadata\x12\x1a\n\x12\x62illable_object_id\x18\x01 \x01(\t2\xd9\t\n\x15\x42illingAccountService\x12\x8b\x01\n\x03Get\x12\x31.yandex.cloud.billing.v1.GetBillingAccountRequest\x1a\'.yandex.cloud.billing.v1.BillingAccount\"(\x82\xd3\xe4\x93\x02\"\x12 /billing/v1/billingAccounts/{id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.billing.v1.ListBillingAccountsRequest\x1a\x34.yandex.cloud.billing.v1.ListBillingAccountsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/billing/v1/billingAccounts\x12\xe6\x01\n\x1aListBillableObjectBindings\x12:.yandex.cloud.billing.v1.ListBillableObjectBindingsRequest\x1a;.yandex.cloud.billing.v1.ListBillableObjectBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings\x12\xf7\x01\n\x12\x42indBillableObject\x12\x32.yandex.cloud.billing.v1.BindBillableObjectRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*3\n\x1a\x42indBillableObjectMetadata\x12\x15\x42illableObjectBinding\x82\xd3\xe4\x93\x02L\"G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings:\x01*\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</billing/v1/billingAccounts/{resource_id}:listAccessBindings\x12\xf7\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\x32>/billing/v1/billingAccounts/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.billing_account_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _GETBILLINGACCOUNTREQUEST.fields_by_name['id']._options = None
  _GETBILLINGACCOUNTREQUEST.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_size']._options = None
  _LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_token']._options = None
  _LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['billing_account_id']._options = None
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_size']._options = None
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BINDBILLABLEOBJECTREQUEST.fields_by_name['billing_account_id']._options = None
  _BINDBILLABLEOBJECTREQUEST.fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BILLINGACCOUNTSERVICE.methods_by_name['Get']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\"\022 /billing/v1/billingAccounts/{id}'
  _BILLINGACCOUNTSERVICE.methods_by_name['List']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/billing/v1/billingAccounts'
  _BILLINGACCOUNTSERVICE.methods_by_name['ListBillableObjectBindings']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['ListBillableObjectBindings']._serialized_options = b'\202\323\344\223\002I\022G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings'
  _BILLINGACCOUNTSERVICE.methods_by_name['BindBillableObject']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['BindBillableObject']._serialized_options = b'\262\322*3\n\032BindBillableObjectMetadata\022\025BillableObjectBinding\202\323\344\223\002L\"G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings:\001*'
  _BILLINGACCOUNTSERVICE.methods_by_name['ListAccessBindings']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002>\022</billing/v1/billingAccounts/{resource_id}:listAccessBindings'
  _BILLINGACCOUNTSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _BILLINGACCOUNTSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C2>/billing/v1/billingAccounts/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETBILLINGACCOUNTREQUEST']._serialized_start=345
  _globals['_GETBILLINGACCOUNTREQUEST']._serialized_end=397
  _globals['_LISTBILLINGACCOUNTSREQUEST']._serialized_start=399
  _globals['_LISTBILLINGACCOUNTSREQUEST']._serialized_end=489
  _globals['_LISTBILLINGACCOUNTSRESPONSE']._serialized_start=491
  _globals['_LISTBILLINGACCOUNTSRESPONSE']._serialized_end=612
  _globals['_LISTBILLABLEOBJECTBINDINGSREQUEST']._serialized_start=615
  _globals['_LISTBILLABLEOBJECTBINDINGSREQUEST']._serialized_end=754
  _globals['_LISTBILLABLEOBJECTBINDINGSRESPONSE']._serialized_start=757
  _globals['_LISTBILLABLEOBJECTBINDINGSRESPONSE']._serialized_end=900
  _globals['_BINDBILLABLEOBJECTREQUEST']._serialized_start=903
  _globals['_BINDBILLABLEOBJECTREQUEST']._serialized_end=1038
  _globals['_BINDBILLABLEOBJECTMETADATA']._serialized_start=1040
  _globals['_BINDBILLABLEOBJECTMETADATA']._serialized_end=1096
  _globals['_BILLINGACCOUNTSERVICE']._serialized_start=1099
  _globals['_BILLINGACCOUNTSERVICE']._serialized_end=2340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1.asymmetricsignature import asymmetric_signature_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key_service.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x46yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto\"\xd8\x03\n#CreateAsymmetricSignatureKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\xa5\x01\n\x06labels\x18\x04 \x03(\x0b\x32X.yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x62\n\x13signature_algorithm\x18\x05 \x01(\x0e\x32\x45.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n$CreateAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"@\n GetAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x83\x01\n\"ListAsymmetricSignatureKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8d\x01\n#ListAsymmetricSignatureKeysResponse\x12M\n\x04keys\x18\x01 \x03(\x0b\x32?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x80\x04\n#UpdateAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12V\n\x06status\x18\x05 \x01(\x0e\x32\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status\x12\xa5\x01\n\x06labels\x18\x06 \x03(\x0b\x32X.yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n$UpdateAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"C\n#DeleteAsymmetricSignatureKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n$DeleteAsymmetricSignatureKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x89\x01\n+ListAsymmetricSignatureKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"~\n,ListAsymmetricSignatureKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\x10\n\x1d\x41symmetricSignatureKeyService\x12\xe7\x01\n\x06\x43reate\x12L.yandex.cloud.kms.v1.asymmetricsignature.CreateAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*>\n$CreateAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x82\xd3\xe4\x93\x02$\"\x1f/kms/v1/asymmetricSignatureKeys:\x01*\x12\xc3\x01\n\x03Get\x12I.yandex.cloud.kms.v1.asymmetricsignature.GetAsymmetricSignatureKeyRequest\x1a?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey\"0\x82\xd3\xe4\x93\x02*\x12(/kms/v1/asymmetricSignatureKeys/{key_id}\x12\xca\x01\n\x04List\x12K.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysRequest\x1aL.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeysResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/kms/v1/asymmetricSignatureKeys\x12\xf0\x01\n\x06Update\x12L.yandex.cloud.kms.v1.asymmetricsignature.UpdateAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*>\n$UpdateAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x82\xd3\xe4\x93\x02-2(/kms/v1/asymmetricSignatureKeys/{key_id}:\x01*\x12\xed\x01\n\x06\x44\x65lete\x12L.yandex.cloud.kms.v1.asymmetricsignature.DeleteAsymmetricSignatureKeyRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*>\n$DeleteAsymmetricSignatureKeyMetadata\x12\x16\x41symmetricSignatureKey\x82\xd3\xe4\x93\x02**(/kms/v1/asymmetricSignatureKeys/{key_id}\x12\xfa\x01\n\x0eListOperations\x12T.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsRequest\x1aU.yandex.cloud.kms.v1.asymmetricsignature.ListAsymmetricSignatureKeyOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/kms/v1/asymmetricSignatureKeys/{key_id}/operations\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/kms/v1/asymmetricSignatureKeys/{resource_id}:listAccessBindings\x12\xef\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/kms/v1/asymmetricSignatureKeys/{resource_id}:setAccessBindings:\x01*\x12\xfb\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G\"B/kms/v1/asymmetricSignatureKeys/{resource_id}:updateAccessBindings:\x01*Bj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms'
  _CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._options = None
  _CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._options = None
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._options = None
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._options = None
  _CREATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _GETASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
  _GETASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['folder_id']._options = None
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTASYMMETRICSIGNATUREKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._options = None
  _UPDATEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _DELETEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._options = None
  _DELETEASYMMETRICSIGNATUREKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Create']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*>\n$CreateAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey\202\323\344\223\002$\"\037/kms/v1/asymmetricSignatureKeys:\001*'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Get']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/kms/v1/asymmetricSignatureKeys/{key_id}'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['List']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/kms/v1/asymmetricSignatureKeys'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Update']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*>\n$UpdateAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey\202\323\344\223\002-2(/kms/v1/asymmetricSignatureKeys/{key_id}:\001*'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Delete']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*>\n$DeleteAsymmetricSignatureKeyMetadata\022\026AsymmetricSignatureKey\202\323\344\223\002**(/kms/v1/asymmetricSignatureKeys/{key_id}'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['ListOperations']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/kms/v1/asymmetricSignatureKeys/{key_id}/operations'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['ListAccessBindings']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002B\022@/kms/v1/asymmetricSignatureKeys/{resource_id}:listAccessBindings'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['SetAccessBindings']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/kms/v1/asymmetricSignatureKeys/{resource_id}:setAccessBindings:\001*'
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _ASYMMETRICSIGNATUREKEYSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002G\"B/kms/v1/asymmetricSignatureKeys/{resource_id}:updateAccessBindings:\001*'
  _globals['_CREATEASYMMETRICSIGNATUREKEYREQUEST']._serialized_start=399
  _globals['_CREATEASYMMETRICSIGNATUREKEYREQUEST']._serialized_end=871
  _globals['_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY']._serialized_start=826
  _globals['_CREATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY']._serialized_end=871
  _globals['_CREATEASYMMETRICSIGNATUREKEYMETADATA']._serialized_start=873
  _globals['_CREATEASYMMETRICSIGNATUREKEYMETADATA']._serialized_end=927
  _globals['_GETASYMMETRICSIGNATUREKEYREQUEST']._serialized_start=929
  _globals['_GETASYMMETRICSIGNATUREKEYREQUEST']._serialized_end=993
  _globals['_LISTASYMMETRICSIGNATUREKEYSREQUEST']._serialized_start=996
  _globals['_LISTASYMMETRICSIGNATUREKEYSREQUEST']._serialized_end=1127
  _globals['_LISTASYMMETRICSIGNATUREKEYSRESPONSE']._serialized_start=1130
  _globals['_LISTASYMMETRICSIGNATUREKEYSRESPONSE']._serialized_end=1271
  _globals['_UPDATEASYMMETRICSIGNATUREKEYREQUEST']._serialized_start=1274
  _globals['_UPDATEASYMMETRICSIGNATUREKEYREQUEST']._serialized_end=1786
  _globals['_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY']._serialized_start=826
  _globals['_UPDATEASYMMETRICSIGNATUREKEYREQUEST_LABELSENTRY']._serialized_end=871
  _globals['_UPDATEASYMMETRICSIGNATUREKEYMETADATA']._serialized_start=1788
  _globals['_UPDATEASYMMETRICSIGNATUREKEYMETADATA']._serialized_end=1842
  _globals['_DELETEASYMMETRICSIGNATUREKEYREQUEST']._serialized_start=1844
  _globals['_DELETEASYMMETRICSIGNATUREKEYREQUEST']._serialized_end=1911
  _globals['_DELETEASYMMETRICSIGNATUREKEYMETADATA']._serialized_start=1913
  _globals['_DELETEASYMMETRICSIGNATUREKEYMETADATA']._serialized_end=1967
  _globals['_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST']._serialized_start=1970
  _globals['_LISTASYMMETRICSIGNATUREKEYOPERATIONSREQUEST']._serialized_end=2107
  _globals['_LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE']._serialized_start=2109
  _globals['_LISTASYMMETRICSIGNATUREKEYOPERATIONSRESPONSE']._serialized_end=2235
  _globals['_ASYMMETRICSIGNATUREKEYSERVICE']._serialized_start=2238
  _globals['_ASYMMETRICSIGNATUREKEYSERVICE']._serialized_end=4332
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Execution(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Execution._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Execution._Status.ValueType  # 0
        QUEUED: Execution._Status.ValueType  # 1
        """Workflow execution is being queued."""
        RUNNING: Execution._Status.ValueType  # 2
        """Workflow execution is running."""
        PAUSED: Execution._Status.ValueType  # 3
        """Workflow execution is being paused."""
        STOPPED: Execution._Status.ValueType  # 4
        """Workflow execution is stopped."""
        FAILED: Execution._Status.ValueType  # 5
        """Workflow execution is failed."""
        FINISHED: Execution._Status.ValueType  # 6
        """Workflow execution is finished."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Execution.Status.ValueType  # 0
    QUEUED: Execution.Status.ValueType  # 1
    """Workflow execution is being queued."""
    RUNNING: Execution.Status.ValueType  # 2
    """Workflow execution is running."""
    PAUSED: Execution.Status.ValueType  # 3
    """Workflow execution is being paused."""
    STOPPED: Execution.Status.ValueType  # 4
    """Workflow execution is stopped."""
    FAILED: Execution.Status.ValueType  # 5
    """Workflow execution is failed."""
    FINISHED: Execution.Status.ValueType  # 6
    """Workflow execution is finished."""

    ID_FIELD_NUMBER: builtins.int
    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Workflow execution. Generated at creation time."""
    workflow_id: builtins.str
    """ID of the Workflow."""
    status: global___Execution.Status.ValueType
    """Status of the Workflow execution"""
    @property
    def input(self) -> global___ExecutionInput:
        """Input data for the Workflow execution."""

    @property
    def result(self) -> global___ExecutionResult:
        """Result of the Workflow execution."""

    @property
    def error(self) -> global___ExecutionError:
        """Error details, in case Workflow execution failed."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the Workflow execution."""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Duration of the Workflow execution."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        workflow_id: builtins.str = ...,
        input: global___ExecutionInput | None = ...,
        result: global___ExecutionResult | None = ...,
        error: global___ExecutionError | None = ...,
        status: global___Execution.Status.ValueType = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "error", b"error", "input", b"input", "result", b"result", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "error", b"error", "id", b"id", "input", b"input", "result", b"result", "started_at", b"started_at", "status", b"status", "workflow_id", b"workflow_id"]) -> None: ...

global___Execution = Execution

@typing.final
class ExecutionPreview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Workflow execution. Generated at creation time."""
    workflow_id: builtins.str
    """ID of the Workflow."""
    status: global___Execution.Status.ValueType
    """Status of the Workflow execution"""
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the Workflow execution."""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Duration of the Workflow execution."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        workflow_id: builtins.str = ...,
        status: global___Execution.Status.ValueType = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "id", b"id", "started_at", b"started_at", "status", b"status", "workflow_id", b"workflow_id"]) -> None: ...

global___ExecutionPreview = ExecutionPreview

@typing.final
class ExecutionInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_JSON_FIELD_NUMBER: builtins.int
    input_json: builtins.str
    """JSON input data for the Workflow execution."""
    def __init__(
        self,
        *,
        input_json: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input", "input_json", b"input_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["input", b"input", "input_json", b"input_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["input", b"input"]) -> typing.Literal["input_json"] | None: ...

global___ExecutionInput = ExecutionInput

@typing.final
class ExecutionResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_JSON_FIELD_NUMBER: builtins.int
    result_json: builtins.str
    """JSON result of the Workflow execution."""
    def __init__(
        self,
        *,
        result_json: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["result", b"result", "result_json", b"result_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["result", b"result", "result_json", b"result_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["result", b"result"]) -> typing.Literal["result_json"] | None: ...

global___ExecutionResult = ExecutionResult

@typing.final
class ExecutionError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_CODE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """Error message of the Workflow execution."""
    error_code: builtins.str
    """Error code of the Workflow execution."""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        error_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_code", b"error_code", "message", b"message"]) -> None: ...

global___ExecutionError = ExecutionError
